@@ -9,7 +9,7 @@ from matplotlib.collections import PatchCollection as PatchColl
 from matplotlib.patches import Rectangle
 from scipy import ndimage
 from subprocess import check_output
-from PIL import Image
+# from PIL import Image
 from .glob_colors import*
 from . import glob_colors as colors
 # Get screen info, remove toolbar
